__copyright__ = 'Copyright (C) 2018 Hiroki Takayasu'
__version__ = '0.0.1'
__license__ = 'MIT'
__author__ = 'Hiroki Takayasu'
__author_email__ = 'hiroki.kana.github@gmail.com'
__url__ = 'https://github.com/hirokikana/paspas'



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import unittest

import paspas.generator

class GeneratorTest(unittest.TestCase):
    site = 'google'
    user = 'bob'
    master = 'secret'
    
    def test_default(self):
        self.assertEqual(paspas.generator.generate(self.site, self.user, self.master), 'NjlmNzJkYzFiMGQzYzQ2YzZlODk4M2JlMTQ0NDFjMzM0MzQ3YWM3MDEzNmFkY2I3NmVhMjkwNzQ0ODczYjA0YmYzZGFlNTRjZTFlN2UzYjBjNWNmOWY2N2Y3ZmMzZjhhODBkYzcxYTk4MTg5ZDBlYWQwYWMyOGNjNTRmZTI3MDc=');

    def test_max_length(self):
        self.assertEqual(paspas.generator.generate(self.site, self.user, self.master, 10), 'NjlmNzJkYz')

    def test_unavailable_char(self):
        self.assertEqual(paspas.generator.generate(self.site, self.user, self.master, 10, 'Nj'), 'lmzJkYzFiM')

if __name__ == '__main__':
    unittest.main()



import hashlib
import base64

def _char_filter(password, unavailable_char):
    for char in unavailable_char:
        password = password.replace(char, '')
    return password
    
def generate(site, user, master_password, max_length=0, unavailable_char=''):
    password = _char_filter(base64.b64encode(hashlib.sha512(site + user + master_password).hexdigest()), unavailable_char)
    if max_length == 0:
        return password
    else:
        return password[0:max_length]
        



from setuptools import setup

requires = ['pyyaml']
setup(
    name='paspas',
    version='0.0.1',
    packages=['paspas'],
    description='Simple password generator for CLI',
    url='https://github.com/hirokikana/paspas',
    author='Hiroki Takayasu',
    author_email='hiroki.kana@gmail.com',
    license='MIT',
    scripts=['bin/paspas'],
    install_requires=requires,
)
